==> mingw-w64-i686-qt6-declarative-6.1.2-4-any.pkg.tar.zst: mingw32/lib/cmake/Qt6QmlTools/Qt6QmlToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qmltyperegistrar" for configuration "Release"
set_property(TARGET Qt6::qmltyperegistrar APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltyperegistrar PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmltyperegistrar-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmltyperegistrar )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmltyperegistrar "${_IMPORT_PREFIX}/bin/qmltyperegistrar-qt6.exe" )

# Import target "Qt6::qmlcachegen" for configuration "Release"
set_property(TARGET Qt6::qmlcachegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlcachegen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmlcachegen-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlcachegen )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlcachegen "${_IMPORT_PREFIX}/bin/qmlcachegen-qt6.exe" )

# Import target "Qt6::qmllint" for configuration "Release"
set_property(TARGET Qt6::qmllint APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmllint PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmllint-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmllint )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmllint "${_IMPORT_PREFIX}/bin/qmllint-qt6.exe" )

# Import target "Qt6::qmlimportscanner" for configuration "Release"
set_property(TARGET Qt6::qmlimportscanner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlimportscanner PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmlimportscanner-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlimportscanner )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlimportscanner "${_IMPORT_PREFIX}/bin/qmlimportscanner-qt6.exe" )

# Import target "Qt6::qmlformat" for configuration "Release"
set_property(TARGET Qt6::qmlformat APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlformat PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmlformat-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlformat )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlformat "${_IMPORT_PREFIX}/bin/qmlformat-qt6.exe" )

# Import target "Qt6::qml" for configuration "Release"
set_property(TARGET Qt6::qml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qml PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qml-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qml )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qml "${_IMPORT_PREFIX}/bin/qml-qt6.exe" )

# Import target "Qt6::qmlprofiler" for configuration "Release"
set_property(TARGET Qt6::qmlprofiler APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlprofiler PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmlprofiler-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlprofiler )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlprofiler "${_IMPORT_PREFIX}/bin/qmlprofiler-qt6.exe" )

# Import target "Qt6::qmlpreview" for configuration "Release"
set_property(TARGET Qt6::qmlpreview APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlpreview PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmlpreview-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlpreview )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlpreview "${_IMPORT_PREFIX}/bin/qmlpreview-qt6.exe" )

# Import target "Qt6::qmlscene" for configuration "Release"
set_property(TARGET Qt6::qmlscene APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlscene PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmlscene-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlscene )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlscene "${_IMPORT_PREFIX}/bin/qmlscene-qt6.exe" )

# Import target "Qt6::qmltime" for configuration "Release"
set_property(TARGET Qt6::qmltime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltime PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmltime.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmltime )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmltime "${_IMPORT_PREFIX}/bin/qmltime.exe" )

# Import target "Qt6::qmlplugindump" for configuration "Release"
set_property(TARGET Qt6::qmlplugindump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlplugindump PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmlplugindump-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlplugindump )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlplugindump "${_IMPORT_PREFIX}/bin/qmlplugindump-qt6.exe" )

# Import target "Qt6::qmltestrunner" for configuration "Release"
set_property(TARGET Qt6::qmltestrunner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltestrunner PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmltestrunner-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmltestrunner )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmltestrunner "${_IMPORT_PREFIX}/bin/qmltestrunner-qt6.exe" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-i686-qt6-declarative-6.2.0-1-any.pkg.tar.zst: mingw32/lib/cmake/Qt6QmlTools/Qt6QmlToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qmltyperegistrar" for configuration "Release"
set_property(TARGET Qt6::qmltyperegistrar APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltyperegistrar PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/share/qt6/bin/qmltyperegistrar.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmltyperegistrar )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmltyperegistrar "${_IMPORT_PREFIX}/share/qt6/bin/qmltyperegistrar.exe" )

# Import target "Qt6::qmlcachegen" for configuration "Release"
set_property(TARGET Qt6::qmlcachegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlcachegen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/share/qt6/bin/qmlcachegen.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlcachegen )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlcachegen "${_IMPORT_PREFIX}/share/qt6/bin/qmlcachegen.exe" )

# Import target "Qt6::qmldom" for configuration "Release"
set_property(TARGET Qt6::qmldom APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmldom PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmldom.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmldom )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmldom "${_IMPORT_PREFIX}/bin/qmldom.exe" )

# Import target "Qt6::qmllint" for configuration "Release"
set_property(TARGET Qt6::qmllint APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmllint PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmllint-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmllint )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmllint "${_IMPORT_PREFIX}/bin/qmllint-qt6.exe" )

# Import target "Qt6::qmlimportscanner" for configuration "Release"
set_property(TARGET Qt6::qmlimportscanner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlimportscanner PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/share/qt6/bin/qmlimportscanner.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlimportscanner )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlimportscanner "${_IMPORT_PREFIX}/share/qt6/bin/qmlimportscanner.exe" )

# Import target "Qt6::qmlformat" for configuration "Release"
set_property(TARGET Qt6::qmlformat APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlformat PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmlformat-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlformat )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlformat "${_IMPORT_PREFIX}/bin/qmlformat-qt6.exe" )

# Import target "Qt6::qml" for configuration "Release"
set_property(TARGET Qt6::qml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qml PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qml-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qml )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qml "${_IMPORT_PREFIX}/bin/qml-qt6.exe" )

# Import target "Qt6::qmlprofiler" for configuration "Release"
set_property(TARGET Qt6::qmlprofiler APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlprofiler PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmlprofiler-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlprofiler )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlprofiler "${_IMPORT_PREFIX}/bin/qmlprofiler-qt6.exe" )

# Import target "Qt6::qmlpreview" for configuration "Release"
set_property(TARGET Qt6::qmlpreview APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlpreview PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmlpreview-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlpreview )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlpreview "${_IMPORT_PREFIX}/bin/qmlpreview-qt6.exe" )

# Import target "Qt6::qmlscene" for configuration "Release"
set_property(TARGET Qt6::qmlscene APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlscene PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmlscene-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlscene )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlscene "${_IMPORT_PREFIX}/bin/qmlscene-qt6.exe" )

# Import target "Qt6::qmltime" for configuration "Release"
set_property(TARGET Qt6::qmltime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltime PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmltime-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmltime )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmltime "${_IMPORT_PREFIX}/bin/qmltime-qt6.exe" )

# Import target "Qt6::qmlplugindump" for configuration "Release"
set_property(TARGET Qt6::qmlplugindump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlplugindump PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmlplugindump-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmlplugindump )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmlplugindump "${_IMPORT_PREFIX}/bin/qmlplugindump-qt6.exe" )

# Import target "Qt6::qmltestrunner" for configuration "Release"
set_property(TARGET Qt6::qmltestrunner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltestrunner PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qmltestrunner-qt6.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmltestrunner )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmltestrunner "${_IMPORT_PREFIX}/bin/qmltestrunner-qt6.exe" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
